<?php
/**
 * @file
 * Default theme implementation to display the basic html structure of a single
 * Drupal page.
 *
 * Variables:
 * - $css: An array of CSS files for the current page.
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $rdf_namespaces: All the RDF namespace prefixes used in the HTML document.
 * - $grddl_profile: A GRDDL profile allowing agents to extract the RDF data.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $page_top: Initial markup from any modules that have altered the
 *   page. This variable should always be output first, before all other dynamic
 *   content.
 * - $page: The rendered page content.
 * - $page_bottom: Final closing markup from any modules that have altered the
 *   page. This variable should always be output last, after all other dynamic
 *   content.
 * - $classes String of classes that can be used to style contextually through
 *   CSS.
 *
 * @see template_preprocess()
 * @see template_preprocess_html()
 * @see template_process()
 */
$html_attributes = "lang=\"{$language->language}\" dir=\"{$language->dir}\" {$rdf->version}{$rdf->namespaces}";

print $doctype; ?>

<!--[if IE 9 ]><html <?php print $html_attributes; ?> class="no-js ie ie9"><![endif]-->
<html <?php print $html_attributes; ?> class="no-js">
<head<?php print $rdf->profile; ?>>
	<?php print $head; ?>

	<!--[if lte IE 9]>
		<div class="no-ie">
			<a href="//windows.microsoft.com/en-us/internet-explorer/download-ie" class="messages error">
				<?php print t('You are using an outdated browser. For a faster, safer browsing experience, upgrade for free today.'); ?>
			</a>
		</div>
	<![endif]-->

	<title><?php print $head_title; ?></title>

	<?php print $styles;
	//print $scripts; ?>

	<!--[if IE 9]>
		<script src="<?php echo base_path().path_to_theme() ?>/js/jquery.placeholder.min.js"></script>
		<script>
			jQuery(document).ready(function() {
				jQuery('input, textarea').placeholder();
			})
		</script>
	<![endif]-->

	<script>
		if (jQuery.cookie('the_cookie') != 0) {
			document.write('<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1.0, user-scalable=no">')
		} else {
			document.write('<meta name="viewport" content="width=device-width">')
		}
	</script>
</head>
<body id="body" class="<?php print $classes; if (theme_get_setting('gatsby_layout_type') == 'boxed') { echo ' boxed'; } ?>" <?php print $attributes;?>>
	<?php // STYLE SWITCHER
	/*if (theme_get_setting('gatsby_styleswitcher_show')) :
		global $theme_root; 
		$curr_uri = request_uri(); ?>
	
		<div id="styleswitcher" class="styleswitcher">
			<button class="sw-invoker color_light open_sw"><span class="lnr lnr-cog"></span></button>
			<div class="sw-inner">
				<div class="sw-section">
					<h6 class="sw-heading"><?php print t('Layout'); ?></h6>
					<div class="gt-switch-view">
						<div class="gt-left-element">
							<button data-layout-type="wide" class="gt-btn-3 gt-reverse gt-active gt-small"><?php print t('Wide'); ?></button>
						</div>
						<div class="gt-right-element">
							<button data-layout-type="boxed" class="gt-btn-3 gt-reverse gt-small"><?php print t('Boxed'); ?></button>
						</div>
					</div>
				</div> <!--gatsby_header_style-->
				<div class="sw-section">
					<h6 class="sw-heading"><?php print t('Header Style'); ?></h6>
					<div class="gt-custom-select">
						<select id="header-type">
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_1') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_1', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_1'; } else { echo $curr_uri . '&header=header_1'; } ?>"><?php print t('Header 1'); ?></option>
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_2') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_2', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_2'; } else { echo $curr_uri . '&header=header_2'; } ?>"><?php print t('Header 2'); ?></option>
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_3') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_3', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_3'; } else { echo $curr_uri . '&header=header_3'; } ?>"><?php print t('Header 3'); ?></option>
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_4') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_4', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_4'; } else { echo $curr_uri . '&header=header_4'; } ?>"><?php print t('Header 4'); ?></option>
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_5') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_5', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_5'; } else { echo $curr_uri . '&header=header_5'; } ?>"><?php print t('Header 5'); ?></option>
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_6') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_6', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_6'; } else { echo $curr_uri . '&header=header_6'; } ?>"><?php print t('Header 6'); ?></option>
							<option <?php if (isset($_GET['header']) && $_GET['header'] == 'header_7') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['header']) && !empty($_GET['header'])) { echo str_replace($_GET['header'], 'header_7', $curr_uri); } elseif (empty($_GET['footer']) && empty($_GET['layout'])) { echo $curr_uri . '?header=header_7'; } else { echo $curr_uri . '&header=header_7'; } ?>"><?php print t('Header 7'); ?></option>
						</select>
					</div>
				</div>
				<div class="sw-section">
					<h6 class="sw-heading"><?php print t('Footer Style'); ?></h6>
					<div class="gt-custom-select">
						<select id="footer-type">
							<option <?php if (isset($_GET['footer']) && $_GET['footer'] == 'footer_1') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['footer']) && !empty($_GET['footer'])) { echo str_replace($_GET['footer'], 'footer_1', $curr_uri); } elseif (empty($_GET['header']) && empty($_GET['layout'])) { echo $curr_uri . '?footer=footer_1'; } else { echo $curr_uri . '&footer=footer_1'; } ?>"><?php print t('Footer 1'); ?></option>
							<option <?php if (isset($_GET['footer']) && $_GET['footer'] == 'footer_2') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['footer']) && !empty($_GET['footer'])) { echo str_replace($_GET['footer'], 'footer_2', $curr_uri); } elseif (empty($_GET['header']) && empty($_GET['layout'])) { echo $curr_uri . '?footer=footer_2'; } else { echo $curr_uri . '&footer=footer_2'; } ?>"><?php print t('Footer 2'); ?></option>
							<option <?php if (isset($_GET['footer']) && $_GET['footer'] == 'footer_3') { echo 'selected="selected"'; } ?> value="<?php if (isset($_GET['footer']) && !empty($_GET['footer'])) { echo str_replace($_GET['footer'], 'footer_3', $curr_uri); } elseif (empty($_GET['header']) && empty($_GET['layout'])) { echo $curr_uri . '?footer=footer_3'; } else { echo $curr_uri . '&footer=footer_3'; } ?>"><?php print t('Footer 3'); ?></option>
						</select>
					</div>
				</div>

				<div class="sw-section">
					<h6 class="sw-heading">Background color</h6>
					<ul class="bg-sw-list bg-color">
						<li><button class="bg-sw-btn gt-active" data-bg-color="#272a2f"></button></li>
						<li><button class="bg-sw-btn" data-bg-color="#e6e7e7"></button></li>
						<li><button class="bg-sw-btn" data-bg-color="#275165"></button></li>
						<li><button class="bg-sw-btn" data-bg-color="#bee6f7"></button></li>
						<li><button class="bg-sw-btn" data-bg-color="#322a53"></button></li>
					</ul>
				</div>
				<div class="sw-section">
					<h6 class="sw-heading">Background image</h6>
					<ul class="bg-sw-list bg-image">
						<li><button class="bg-sw-btn gt-active" data-bg-image="images/image_bg_1.jpg"></button></li>
						<li><button class="bg-sw-btn" data-bg-image="images/image_bg_2.jpg"></button></li>
						<li><button class="bg-sw-btn" data-bg-image="images/image_bg_3.jpg"></button></li>
					</ul>
				</div>
				<button type="reset"  class="gt-btn-3 gt-small gt-sw-reset"><?php print t('Reset'); ?></button>
				
				<p class="m_bottom_5">Background for boxed layout</p>
				<div class="custom_select relative f_size_medium m_bottom_10">
					<div class="select_title type_2 r_corners relative mw_0">Color</div>
					<ul class="select_list d_none"></ul>
					<select name="bg_color">
						<option value="Image">Image</option>
						<option value="Color">Color</option>
					</select>
				</div>
				<div class="m_bottom_20 bg_select_color">
					<p class="d_inline_middle">Background :</p><button class="d_inline_middle r_corners m_left_10" id="select_color"></button>
				</div>
				<div class="m_bottom_20 bg_select_image d_none">
					<p class="d_inline_middle m_right_10 m_bottom_5">Background image:</p>
					<button class="d_inline_middle bg_image_button r_corners m_right_5 m_bottom_5" data-image="<?php echo $theme_root; ?>/images/patterns/item-3.png"></button>
					<button class="d_inline_middle bg_image_button r_corners m_right_5 m_bottom_5" data-image="<?php echo $theme_root; ?>/images/patterns/item-8.png"></button>
				</div>
				<button type="reset" class="button_type_4 r_corners tr_all_hover color_dark mw_0 bg_light_color_2">Reset</button>
			</div>
		</div>
	<?php endif;
	*/// END STYLE SWITCHER
	
	print $page_top;
	print $page;
	print $page_bottom;
	print $scripts; /*?>
	
	<script>
		(function($){
			$(document).ready(function(){
				var hSelect = $('[name="header_type"]'),
					fSelect = $('[name="footer_type"]');

				<?php // Header setting
				/*if (isset($_GET['header'])) {
					$header_option = $_GET['header'];
				} elseif ($is_page_header) {
					$header_option = $header_option_page;
				} else {*/
					/*$header_option = theme_get_setting('gatsby_header_style');
				//}
				
				switch ($header_option) :
					case 'header_1': ?>
						// Setting Header 1
						hSelect.prevAll(".select_title").text('Header 1');
						<?php break;
					case 'header_2': ?>
						// Setting Header 2
						$('.main_menu').addClass('type_2');
						$('.main_menu .f_xs_none').addClass('m_left_10 m_xs_left_0');
						$('.main_menu .color_light').removeClass('color_light').addClass('color_dark r_corners');
						hSelect.prevAll(".select_title").text('Header 2');
						<?php break;
					case 'header_3': ?>
						// Setting Header 3
						hSelect.prevAll(".select_title").text('Header 3');
						<?php break;
					case 'header_4': ?>
						// Setting Header 4
						$('.main_menu').addClass('type_3');
						$('.main_menu li.m_xs_bottom_5').addClass('m_left_40 m_sm_left_10 m_md_left_25 m_xs_left_0');
						$('.main_menu .color_light').removeClass('color_light').addClass('color_dark r_corners');
						hSelect.prevAll(".select_title").text('Header 4');
						<?php break;
					case 'header_5': ?>
						// Setting Header 5
						$('.main_menu').addClass('type_2 header_5');
						hSelect.prevAll(".select_title").text('Header 5');
						<?php break;
					default:
						break;
				endswitch; ?>

				<?php // Footer seting
				/*if (isset($_GET['footer'])) {
					$footer_option = $_GET['footer'];
				} elseif ($is_page_footer) {
					$footer_option = $footer_option_page;
				} else {*/
					/*$footer_option = theme_get_setting('gatsby_footer_style');
				//}
				
				switch ($footer_option) :
					case 'footer_1': ?>
						// Setting Footer 1
						fSelect.prevAll(".select_title").text('Footer 1');
						<?php break;
					case 'footer_2': ?>
						// Setting Footer 2
						fSelect.prevAll(".select_title").text('Footer 2');
						<?php break;
					case 'footer_3': ?>
						// Setting Footer 3
						fSelect.prevAll(".select_title").text('Footer 3');
						<?php break;
					case 'footer_4': ?>
						// Setting Footer 4
						fSelect.prevAll(".select_title").text('Footer 4');
						<?php break;
					case 'footer_5:': ?>
						// Setting Footer 5
						fSelect.prevAll(".select_title").text('Footer 5');
						<?php break;
					case 'footer_6:': ?>
						// Setting Footer 6
						fSelect.prevAll(".select_title").text('Footer 6');
						<?php break;
					default:
						break;
				endswitch;

				// If enable Switcher
				if (theme_get_setting('switcher') == 1) :
					if ($layout_option == 'boxed_layout') { ?>
						$('#styleswitcher .layout_boxed').addClass('active');
					<?php } else { ?>
						$('#styleswitcher .layout_wide').addClass('active');
					<?php }
					
					if(theme_get_setting('background_type') == 'color' && theme_get_setting('background_color')!='') : ?>
						var sc = $('#select_color');
						sc.ColorPicker({
							color: '<?php print theme_get_setting('background_color'); ?>',
							onShow: function (colpkr){
								$(colpkr).fadeIn(500);
								return false;
							},
							onHide: function (colpkr) {
								$(colpkr).fadeOut(500);
								return false;
							},
							onChange: function (hsb, hex, rgb){
								$('body').css('background-image','none');
								$('#select_color,body').css('backgroundColor', '#' + hex);
							}
						});
					<?php endif; ?>
					var sw			= $('#styleswitcher'),
						layout		= jQuery('[class*="_layout"]'),
						color		= jQuery('.bg_select_color'),
						bgSelect	= jQuery('select[name="bg_color"]'),
						image		= jQuery('.bg_select_image'),
						reset		= sw.find('button[type="reset"]');

					reset.on('click', function() {
						var h = $('[role="banner"]'),
							f = $('.footer_top_part');

						$('body, #select_color').css({
							<?php if (theme_get_setting('background_type') == 'image' && theme_get_setting('background_image') != '') : ?>
								'backgroundImage' : 'url(<?php echo $theme_root; ?>/images/patterns/<?php print theme_get_setting('background_image'); ?>.png)',
							<?php endif; 
							if(theme_get_setting('background_type') == 'color' && theme_get_setting('background_color') != '') : ?>
								'backgroundColor' : '<?php print theme_get_setting('background_color'); ?>',
								'backgroundImage' : 'none'
							<?php endif; ?>
						});

						if (!(sw.find('.homepage').length)) {
							sw.find('[data-layout]').removeClass('active');
							<?php if ($layout_option == 'boxed_layout') { ?>
								layout.removeClass('wide_layout').addClass('boxed_layout');
								$('#styleswitcher .layout_boxed').addClass('active');
							<?php } else { ?>
								layout.removeClass('boxed_layout').addClass('wide_layout');
								$('#styleswitcher .layout_wide').addClass('active');
							<?php } ?>
						}

						image.slideUp(function(){
							color.slideDown();
						});

						bgSelect.prevAll(".select_title").text('Color');
						bgSelect.prev('.select_list').children('li').removeClass('active').first().addClass('active');
					});
				<?php endif; ?>
			})
		})(jQuery);
	</script>*/ ?>
</body>
</html>