<?php
/**
 * @file
 * Implementation to display a single Drupal page while offline.
 *
 * All the available variables are mirrored in page.tpl.php.
 *
 * @see template_preprocess()
 * @see template_preprocess_maintenance_page()
 * @see gatsby_process_maintenance_page()
 */
$html_attributes = "lang=\"{$language->language}\" dir=\"{$language->dir}\" {$rdf->version}{$rdf->namespaces}";

print $doctype; ?>

<!--[if IE 9 ]><html <?php print $html_attributes; ?> class="no-js ie ie9"><![endif]-->
<html <?php print $html_attributes; ?> class="no-js">
<head<?php print $rdf->profile; ?>>
	<?php print $head; ?>

	<!--[if lte IE 9]>
		<div class="no-ie">
			<a href="//windows.microsoft.com/en-us/internet-explorer/download-ie" class="messages error">
				<?php print t('You are using an outdated browser. For a faster, safer browsing experience, upgrade for free today.'); ?>
			</a>
		</div>
	<![endif]-->

	<title><?php print $head_title; ?></title>

	<?php print $styles;
	print $scripts; ?>

	<!--[if IE 9]>
		<script src="<?php echo base_path().path_to_theme() ?>/js/jquery.placeholder.min.js"></script>
		<script>
			jQuery(document).ready(function() {
				jQuery('input, textarea').placeholder();
			})
		</script>
	<![endif]-->

	<script>
		if (jQuery.cookie('the_cookie') != 0) {
			document.write('<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1.0, user-scalable=no">')
		} else {
			document.write('<meta name="viewport" content="width=device-width">')
		}
	</script>

	<link rel="stylesheet" href="<?php echo base_path().path_to_theme() ?>/css/style-mobile.css" media="screen" id="style-mobile">
	<link rel="stylesheet" href="<?php echo base_path().path_to_theme() ?>/css/grid-mobile.css" media="screen" id="grid-mobile">
</head>
<body id="body" class="<?php print $classes; if (theme_get_setting('gatsby_layout_type') == 'boxed') { echo ' boxed'; } ?>" <?php print $attributes;?>>
	<?php print $page_top; ?>

	<div id="page-wrapper" class="page-wrapper">
		<div id="page" class="page">
			<!-- Header
			======================================================================================= -->
			<header id="header" class="header page-header clearfix" role="banner">
				<div class="header-section-1<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
					<div class="container-12">
						<div class="grid-12">
							<?php // Logo
							if ($logo || $site_name || $site_slogan) :?>
								<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
									<?php // logo image
									if ($logo) : ?>
										<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
											<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
										</a>
									<?php endif;
	
									// site name
									if ($site_name) : ?>
										<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
											<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
										</div>
									<?php endif;
	
									// site slogan
									if ($site_slogan) : ?>
										<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
											<?php print $site_slogan; ?>
										</div>
									<?php endif; ?>
								</div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</header>
	
			<!-- Content
			======================================================================================= -->
			<div id="main-wrapper" class="main-wrapper" role="main">
				<?php if ($title) : ?>
					<header id="content-header" class="header content-header">
						<div class="container-12">
							<div class="grid-6">
								<?php // Page title
								print render($title_prefix);
								if ($title) :
									print render($title_prefix); ?>
										<h2 id="page-title" class="title page-title" ><?php print $title; ?></h2>
									<?php print render($title_suffix);
								endif;
								print render($title_suffix);
								print render($primary_local_tasks); ?>
							</div>
						</div>
					</header>
				<?php endif; ?>
				<div id="main" class="main">
					<div class="container-12">
						<div class="grid-12">
							<div id="content" class="content content-main">
									<!-- Page content -->
									<div class="region">
										<?php print $content; ?>
									</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>

	<?php print $page_bottom; ?>
</body>
</html>