<?php

/**
 * @file
 * Default theme implementation to display a node.
 *
 * Available variables:
 * - $title: the (sanitized) title of the node.
 * - $content: An array of node items. Use render($content) to print them all,
 *	 or print a subset such as render($content['field_example']). Use
 *	 hide($content['field_example']) to temporarily suppress the printing of a
 *	 given element.
 * - $user_picture: The node author's picture from user-picture.tpl.php.
 * - $date: Formatted creation date. Preprocess functions can reformat it by
 *	 calling format_date() with the desired parameters on the $created variable.
 * - $name: Themed username of node author output from theme_username().
 * - $node_url: Direct url of the current node.
 * - $display_submitted: whether submission information should be displayed.
 * - $classes: String of classes that can be used to style contextually through
 *	 CSS. It can be manipulated through the variable $classes_array from
 *	 preprocess functions. The default values can be one or more of the
 *	 following:
 *	 - node: The current template type, i.e., "theming hook".
 *	 - node-[type]: The current node type. For example, if the node is a
 *		 "Blog entry" it would result in "node-blog". Note that the machine
 *		 name will often be in a short form of the human readable label.
 *	 - node-teaser: Nodes in teaser form.
 *	 - node-preview: Nodes in preview mode.
 *	 The following are controlled through the node publishing options.
 *	 - node-promoted: Nodes promoted to the front page.
 *	 - node-sticky: Nodes ordered above other non-sticky nodes in teaser
 *		 listings.
 *	 - node-unpublished: Unpublished nodes visible only to administrators.
 * - $title_prefix (array): An array containing additional output populated by
 *	 modules, intended to be displayed in front of the main title tag that
 *	 appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *	 modules, intended to be displayed after the main title tag that appears in
 *	 the template.
 *
 * Other variables:
 * - $node: Full node object. Contains data that may not be safe.
 * - $type: Node type, i.e. story, page, blog, etc.
 * - $comment_count: Number of comments attached to the node.
 * - $uid: User ID of the node author.
 * - $created: Time the node was published formatted in Unix timestamp.
 * - $classes_array: Array of html class attribute values. It is flattened
 *	 into a string within the variable $classes.
 * - $zebra: Outputs either "even" or "odd". Useful for zebra striping in
 *	 teaser listings.
 * - $id: Position of the node. Increments each time it's output.
 *
 * Node status variables:
 * - $view_mode: View mode, e.g. 'full', 'teaser'...
 * - $teaser: Flag for the teaser state (shortcut for $view_mode == 'teaser').
 * - $page: Flag for the full page state.
 * - $promote: Flag for front page promotion state.
 * - $sticky: Flags for sticky post setting.
 * - $status: Flag for published status.
 * - $comment: State of comment settings for the node.
 * - $readmore: Flags true if the teaser content of the node cannot hold the
 *	 main body content.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 *
 * Field variables: for each field instance attached to the node a corresponding
 * variable is defined, e.g. $node->body becomes $body. When needing to access
 * a field's raw values, developers/themers are strongly encouraged to use these
 * variables. Otherwise they will have to explicitly specify the desired field
 * language, e.g. $node->body['en'], thus overriding any language negotiation
 * rule that was previously applied.
 *
 * @see template_preprocess()
 * @see template_preprocess_node()
 * @see template_process()
 */
?>
<div id="node-<?php print $node->nid; ?>" class="<?php print $classes; ?> clearfix node-<?php print $node->nid; ?>" role="article"<?php print $attributes; ?>>
	<?php if (module_exists('statistics')) :
		$hitcount = statistics_get($node->nid);
		unset($content['links']['statistics']);
	endif;
	
	if (module_exists('vud') && field_info_field('field_blog_like') != NULL) :
		hide($content['field_blog_like']);
	endif;

	if ($title || $user_picture || $display_submitted) : ?>
		<header class="header node-header clearfix">
			<?php // Node title
			if ($title && !$page) :
				print render($title_prefix); ?>
					<h6 class="title node-title"<?php print $title_attributes; ?>>
						<a href="<?php print $node_url; ?>" rel="bookmark"><?php print $title; ?></a>
					</h6>
				<?php print render($title_suffix);
			endif;
			
			// Node meta
			if ($display_submitted) : ?>
				<div class="meta node-meta" role="contentinfo">
					<?php if ($submitted_pubdate && theme_get_setting('gatsby_meta_date')) : // publish date ?>
						<time class="node-pubdate" datetime="<?php print $submitted_pubdate; ?>">
							</span> <?php print $submitted_date; ?>
						</time>
					<?php endif;
					
					if (module_exists('vud') && $node->type == 'blog') : ?>
						<span class="node-likes"><?php print render($content['field_blog_like']); ?></span>
					<?php endif;
					
					if (theme_get_setting('gatsby_meta_comments')) : // node comments?>
						<span class="node-comments">
							<a href="<?php echo $node_url;?>#comments" class="node-comments"><?php print format_plural($comment_count, '1 comment', '@count comments'); ?> </a>
						</span>
					<?php endif; ?>
				</div>
			<?php endif; ?>
		</header>
	<?php endif; ?>

	<div class="content node-content"<?php print $content_attributes; ?>>
		<?php // Hide the comments, tags and links
		hide($content['comments']);
		hide($content['links']);
		hide($content['field_tags']);
		
		// Hide read more
		if (theme_get_setting('gatsby_links_hide_readmore')) {
			hide($content['links']['node']);
		}
		
		// Hide admin's blog
		if (theme_get_setting('gatsby_links_hide_readblog')) {
			hide($content['links']['blog']); 
		}
		
		// Hide add new comment
		if (theme_get_setting('gatsby_links_hide_addcomment')) {
			unset($content['links']['comment']['#links']['comment-add']);
		}
		
		// Hide number of comments
		if (theme_get_setting('gatsby_links_hide_commentsnum')) {
			unset($content['links']['comment']['#links']['comment-comments']);
		}
		
		// Hide number of new comments
		if (theme_get_setting('gatsby_links_hide_commentsnew')) {
			unset($content['links']['comment']['#links']['comment-new-comments']);
		}
		
		//print_r($content['body']);

		// Node content
		/*if ($view_mode == 'full'):
			$body = field_get_items('node', $node, 'body');
			
			if ($body[0]['summary']) :
				$content['body']['und'][0]['value'] = '<div class="summary node-summary">' .
					$body[0]['summary'] .
				'</div>' . $content['body']['und'][0]['value'];
			endif;
		endif;*/
		
		print render($content); ?>
	</div>

	<?php if (!empty($content['field_tags']) || !empty($content['links'])) : ?>
		<footer class="footer node-footer" role="contentinfo">
			<?php // Node tags
			print render($content['field_tags']);
			
			// Node links
			if ($links = render($content['links'])): ?>
				<div class="node-links clearfix">
					<?php print $links; ?>
				</div>
			<?php endif; ?>
		</footer>
	<?php endif;
	
	// Node bottom region
	if ($node_bottom) :
		print render($node_bottom);
	endif;
	
	// Node comments
	print render($content['comments']); ?>
</div>