<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *	 least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *	 or themes/garland.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *	 when linking to the front page. This includes the language domain or
 *	 prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *	 in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *	 in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *	 site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *	 the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *	 modules, intended to be displayed in front of the main title tag that
 *	 appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *	 modules, intended to be displayed after the main title tag that appears in
 *	 the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *	 prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *	 (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *	 menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *	 associated with the page, and the node ID is the second argument
 *	 in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *	 comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content_top']: Items for the header region.
 * - $page['content']: The main content of the current page.
 * - $page['content_bottom']: Items for the header region.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 */
?>


<?php if (!theme_get_setting('gatsby_breadcrumb_show')) :
	$breadcrumb = NULL;
endif; ?>

<?php if ($main_menu) : ?>
	<a href="#main-menu" class="element-invisible element-focusable"><?php print t('Skip to navigation'); ?></a>
<?php endif; ?>
<a href="#content" class="element-invisible element-focusable"><?php print t('Skip to main content'); ?></a>


<div id="page-wrapper" class="page-wrapper">
	<div id="preloader" class="gt-preloader"></div>

	<div id="page" class="page">
		<!-- Header
		======================================================================================= -->
		<header id="header" class="header page-header clearfix <?php print theme_get_setting('gatsby_header_style'); ?>" role="banner">
			<?php switch(theme_get_setting('gatsby_header_style')) {
				case 'header_2': ?>
					<div class="gt-header<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
						<div class="container-12">
							<div class="grid-2">
								<?php // Logo
								if ($logo || $site_name || $site_slogan) :?>
									<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
										<?php // logo image
										if ($logo) : ?>
											<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
												<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
											</a>
										<?php endif;
		
										// site name
										if ($site_name) : ?>
											<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
												<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
											</div>
										<?php endif;
		
										// site slogan
										if ($site_slogan) : ?>
											<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
												<?php print $site_slogan; ?>
											</div>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>
		
							<?php // Region Menu
							if ($page['menu_2']) : ?>
								<div class="grid-8">
									<div id="region-menu-wrapper" class="region-menu-wrapper align-center">
										<?php print render($page['menu_2']); ?>
									</div>
								</div>
							<?php endif;
							
							// Region Header right
							if ($page['header_right_2']) : ?>
								<div class="grid-2 float-right">
									<div id="region-header-right-wrapper" class="region-header-right-wrapper">
										<?php print render($page['header_right_2']); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<?php break;
				case 'header_3': ?>
					<div class="gt-header<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
						<div class="container-12">
							<div class="grid-3">
								<?php // Logo
								if ($logo || $site_name || $site_slogan) :?>
									<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
										<?php // logo image
										if ($logo) : ?>
											<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
												<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
											</a>
										<?php endif;
		
										// site name
										if ($site_name) : ?>
											<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
												<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
											</div>
										<?php endif;
		
										// site slogan
										if ($site_slogan) : ?>
											<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
												<?php print $site_slogan; ?>
											</div>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>
		
							<?php // Region Menu
							if ($page['menu_3']) : ?>
								<div class="grid-6">
									<div id="region-menu-wrapper" class="region-menu-wrapper">
										<?php print render($page['menu_3']); ?>
									</div>
								</div>
							<?php endif;
							
							// Region Header right
							if ($page['header_right_3']) : ?>
								<div class="grid-3 float-right">
									<div id="region-header-right-wrapper" class="region-header-right-wrapper">
										<?php print render($page['header_right_3']); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<?php break;
				case 'header_4': ?>
					<div class="gt-header">
						<div class="container-12">
							<?php // Region Header left
							if ($page['header_left_4']) : ?>
								<div class="grid-4">
									<div id="region-header-left-wrapper" class="region-header-left-wrapper">
										<?php print render($page['header_left_4']); ?>
									</div>
								</div>
							<?php endif; ?>

							<div class="<?php if (($page['header_left_4']) && ($page['header_right_4'])) : print 'grid-4'; elseif ($page['header_left_4']) : print 'grid-8'; elseif ($page['header_right_4']) : print 'grid-8';  else : print 'grid-12'; endif; ?> align-center">
								<?php // Logo
								if ($logo || $site_name || $site_slogan) :?>
									<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
										<?php // logo image
										if ($logo) : ?>
											<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
												<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
											</a>
										<?php endif;
		
										// site name
										if ($site_name) : ?>
											<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
												<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
											</div>
										<?php endif;
		
										// site slogan
										if ($site_slogan) : ?>
											<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
												<?php print $site_slogan; ?>
											</div>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>
							
							<?php // Region Header right
							if ($page['header_right_4']) : ?>
								<div class="grid-4">
									<div id="region-header-right-wrapper" class="region-header-right-wrapper">
										<?php print render($page['header_right_4']); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<?php // Region Menu
					if ($page['menu_4']) : ?>
						<div id="region-menu-wrapper" class="region-menu-wrapper<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['menu_4']); ?>
								</div>
							</div>
						</div>
					<?php endif; 
					break;
				case 'header_5':
					// Region Header top
					if ($page['header_top']) : ?>
						<div id="region-header-top-wrapper" class="region-header-top-wrapper">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['header_top']); ?>
								</div>
							</div>
						</div>
					<?php endif; ?>
					
					<div class="gt-header">
						<div class="container-12">
							<div class="grid-2">
								<?php // Logo
								if ($logo || $site_name || $site_slogan) :?>
									<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
										<?php // logo image
										if ($logo) : ?>
											<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
												<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
											</a>
										<?php endif;
		
										// site name
										if ($site_name) : ?>
											<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
												<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
											</div>
										<?php endif;
		
										// site slogan
										if ($site_slogan) : ?>
											<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
												<?php print $site_slogan; ?>
											</div>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>

							<?php // Region Header right
							if ($page['header_right_5']) : ?>
								<div class="grid-10">
									<div id="region-header-right-wrapper" class="region-header-right-wrapper">
										<?php print render($page['header_right_5']); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<?php // Region Menu
					if ($page['menu_5']) : ?>
						<div id="region-menu-wrapper" class="region-menu-wrapper<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['menu_5']); ?>
								</div>
							</div>
						</div>
					<?php endif;
					break;
				case 'header_6': ?>
					<div class="gt-header<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
						<div class="container-12">
							<div class="grid-2">
								<?php // Logo
								if ($logo || $site_name || $site_slogan) :?>
									<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
										<?php // logo image
										if ($logo) : ?>
											<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
												<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
											</a>
										<?php endif;
		
										// site name
										if ($site_name) : ?>
											<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
												<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
											</div>
										<?php endif;
		
										// site slogan
										if ($site_slogan) : ?>
											<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
												<?php print $site_slogan; ?>
											</div>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>
		
							<?php // Region Menu
							if ($page['menu_6']) : ?>
								<div class="grid-10">
									<div id="region-menu-wrapper" class="region-menu-wrapper">
										<?php print render($page['menu_6']); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<?php break;
				case 'header_7': ?>
					<div class="gt-header">
						<div class="container-12">
							<?php // Region Header left
							if ($page['header_left_7']) : ?>
								<div class="grid-3">
									<div id="region-header-left-wrapper" class="region-header-left-wrapper">
										<?php print render($page['header_left_7']); ?>
									</div>
								</div>
							<?php endif; ?>

							<div class="<?php if (($page['header_left_7']) && ($page['header_right_7'])) : print 'grid-6'; elseif ($page['header_left_7']) : print 'grid-9'; elseif ($page['header_right_7']) : print 'grid-9';  else : print 'grid-12'; endif; ?> align-center">
								<?php // Logo
								if ($logo || $site_name || $site_slogan) :?>
									<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
										<?php // logo image
										if ($logo) : ?>
											<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
												<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
											</a>
										<?php endif;
		
										// site name
										if ($site_name) : ?>
											<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
												<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
											</div>
										<?php endif;
		
										// site slogan
										if ($site_slogan) : ?>
											<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
												<?php print $site_slogan; ?>
											</div>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>
							
							<?php // Region Header right
							if ($page['header_right_7']) : ?>
								<div class="grid-3">
									<div id="region-header-right-wrapper" class="region-header-right-wrapper">
										<?php print render($page['header_right_7']); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<?php // Region Menu
					if ($page['menu_7']) : ?>
						<div id="region-menu-wrapper" class="region-menu-wrapper<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } ?>">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['menu_7']); ?>
								</div>
							</div>
						</div>
					<?php endif; 
					break;
				default: ?>
					<div class="gt-header">
						<div class="gt-header-inner<?php if (theme_get_setting('gatsby_sticky_menu')) { echo ' stickup'; } if ($page['header_section_1'] || $page['header_section_2']) { echo ' gt-fixed'; } ?>">
							<div class="container-12">
								<div class="grid-2">
									<?php // Logo
									if ($logo || $site_name || $site_slogan) :?>
										<div id="site-branding" class="site-branding<?php if (!($site_name && $site_slogan)) echo ' only-logo'; ?>">
											<?php // logo image
											if ($logo) : ?>
												<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-branding-logo" class="site-branding-logo">
													<img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>">
												</a>
											<?php endif;
			
											// site name
											if ($site_name) : ?>
												<div title="<?php print $site_name; ?>" id="site-branding-name" class="site-branding-name">
													<a href="<?php print $front_page; ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a>
												</div>
											<?php endif;
			
											// site slogan
											if ($site_slogan) : ?>
												<div title="<?php print $site_slogan; ?>" id="site-branding-slogan" class="site-branding-slogan">
													<?php print $site_slogan; ?>
												</div>
											<?php endif; ?>
										</div>
									<?php endif; ?>
								</div>
			
								<?php // Region Menu
								if ($page['menu']) : ?>
									<div class="grid-10">
										<div id="region-menu-wrapper" class="region-menu-wrapper">
											<?php print render($page['menu']); ?>
										</div>
									</div>
								<?php endif; ?>
							</div>
						</div>
					</div>
					<?php break;
			} ?>

			<?php // Region Header section 1
			if ($page['header_section_1']) : 
				gatsby_region_preffix ('header_section_1');
					print render($page['header_section_1']);
				gatsby_region_suffix ('header_section_1');
			endif;

			// Region Header section 2
			if ($page['header_section_2']) : 
				gatsby_region_preffix ('header_section_2');
					print render($page['header_section_2']);
				gatsby_region_suffix ('header_section_2');
			endif; ?>
		</header>

		<!-- Content
		======================================================================================= -->
		<div id="main-wrapper" class="main-wrapper" role="main">
			<?php if ($breadcrumb && $title && !$is_front) : ?>
				<header id="content-header" class="header content-header align-center">
					<div class="container-12">
						<div class="grid-12">
							<?php // Page title
							print render($title_prefix);
							if ($title && !$is_front) :
								print render($title_prefix); ?>
									<h1 id="page-title" class="title page-title" ><?php print $title; ?></h1>
								<?php print render($title_suffix);
							endif;
							print render($title_suffix);
							print render($primary_local_tasks);
							
							// Breadcrumbs
							if ($breadcrumb) : ?>
								<div id="breadcrumb" class="breadcrumb clearfix"><?php print $breadcrumb; ?></div>
							<?php endif; ?>
						</div>
					</div>
				</header>
			<?php endif;
			
			if (!empty($page['highlighted']) || !empty($page['help']) || $messages) : ?>
				<div id="content-subheader" class="content-subheader">
					<div class="container-12">
						<div class="grid-12">
							<?php // System messages
							if ($messages) : ?>
								<div id="messages" class="messages-wrapper clearfix">
									<?php print $messages; ?>
								</div>
							<?php endif;

							// Highlighted
							if ($page['highlighted']) : ?>
								<div id="highlighted" class="highlighted"><?php print render($page['highlighted']); ?></div>
							<?php endif;

							// System help block
							if ($page['help']): ?>
								<div id="system-help" class="system-help"><?php print render($page['help']); ?></div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			<?php endif; ?>
			
			<div class="regions-wrapper">
				<?php if ($page['content_top']) : 
					gatsby_region_preffix ('content_top');
						print render($page['content_top']);
					gatsby_region_suffix ('content_top');
				endif; ?>
				
				<div id="main" class="main region-wrapper">
					<div class="container-12">
						<div class="grid-12">
							<?php // Region Left sidebar
							if ($page['sidebar_first']) : ?>
								<aside id="sidebar-first" class="sidebar-first sidebar grid-4 alpha" role="complementary">
									<?php print render($page['sidebar_first']); ?>
								</aside>
							<?php endif; ?>
	
							<div id="content" class="content content-main <?php if (($page['sidebar_first']) && ($page['sidebar_second'])) : print 'grid-4'; elseif ($page['sidebar_first']) : print 'grid-8 omega'; elseif ($page['sidebar_second']) : print 'grid-8 alpha'; endif; ?>">
								<?php if (!empty($tabs['#primary']) || !empty($action_links)) : ?>
									<?php // Tabs links
									if (!empty($tabs['#primary'])) : ?>
										<div class="tabs tabs-primary">
											<ul class="tabs primary">
												<?php print render($tabs['#primary']); ?>
											</ul>
										</div>
									<?php endif;
									
									// Tabs links
									if (!empty($tabs['#secondary'])) : ?>
										<div class="tabs-secondary">
											<ul class="tabs secondary">
												<?php print render($tabs['#secondary']); ?>
											</ul>
										</div>
									<?php endif;
								
									// Action links
									if ($action_links) : ?>
										<ul class="action-links">
											<?php print render($action_links); ?>
										</ul>
									<?php endif; ?>
								<?php endif;
								
								// Region Page content
								print render($page['content']); ?>
							</div>
	
							<?php // Region Right sidebar
							if ($page['sidebar_second']) : ?>
								<aside id="sidebar-second" class="sidebar-second sidebar grid-4 omega" role="complementary">
									<div class="section">
										<?php print render($page['sidebar_second']); ?>
									</div>
								</aside>
							<?php endif; ?>
						</div>
					</div>
				</div>
					
				<?php // Region Section 1 - Section 10
				for ($i = 1; $i <= 30; $i++) {
					if ($page['content_section_' . $i]) : 
						gatsby_region_preffix ('content_section_' . $i);
							print render($page['content_section_' . $i]);
						gatsby_region_suffix ('content_section_' . $i);
					endif;
				}
				
				// Region Content bottom
				if ($page['content_bottom']) : 
					gatsby_region_preffix ('content_bottom');
						print render($page['content_bottom']);
					gatsby_region_suffix ('content_bottom');
				endif; ?>
			</div>
		</div>

		<!-- Footer
		======================================================================================= -->
		<footer id="footer" class="footer page-footer" role="contentinfo">
			<?php switch(theme_get_setting('gatsby_footer_style')) {
				case 'footer_2':
					if ($page['footer_section_1'] || $page['footer_section_2'] || $page['footer_section_3'] || $page['footer_section_4'] || $page['footer_section_5']) : ?>
						<div class="region-footer-top-wrapper footer-2">
							<div class="container-12">
								<?php // Region Footer section 1
								if ($page['footer_section_1']) :?>
									<div class="grid-2">
										<?php print render($page['footer_section_1']); ?>
									</div>
								<?php endif;
								
								// Region Footer section 2
								if ($page['footer_section_2']) :?>
									<div class="grid-2">
										<?php print render($page['footer_section_2']); ?>
									</div>
								<?php endif;
								
								// Region Footer section 3
								if ($page['footer_section_3']) :?>
									<div class="grid-2">
										<?php print render($page['footer_section_3']); ?>
									</div>
								<?php endif;
								
								// Region Footer section 4
								if ($page['footer_section_4']) :?>
									<div class="grid-3">
										<?php print render($page['footer_section_3']); ?>
									</div>
								<?php endif;
								
								// Region Footer section 5
								if ($page['footer_section_5']) :?>
									<div class="grid-3">
										<?php print render($page['footer_section_5']); ?>
									</div>
								<?php endif; ?>
							</div>
						</div>
					<?php endif;
					
					// Region Footer
					if ($page['footer_2']) : ?>
						<div class="region-footer-wrapper">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['footer_2']); ?>
								</div>
							</div>
						</div>
					<?php endif;
					break;
				case 'footer_3':
					// Region Footer top
					if ($page['footer_top']) : ?>
						<div class="region-footer-top-wrapper footer-3">
							<div class="container-12">
								<?php print render($page['footer_top']); ?>
							</div>
						</div>
					<?php endif;
					
					// Region Footer
					if ($page['footer_3']) : ?>
						<div class="region-footer-wrapper">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['footer_3']); ?>
								</div>
							</div>
						</div>
					<?php endif;
					break;
				default:
					if ($page['footer_triptych_1'] || $page['footer_triptych_2'] || $page['footer_triptych_3']) : ?>
						<div class="region-footer-top-wrapper footer-1">
							<div class="container-12">
								<?php // Region Footer triptych 1
								if ($page['footer_triptych_1']) :?>
									<div class="grid-3 suffix-1">
										<?php print render($page['footer_triptych_1']); ?>
									</div>
								<?php endif;
								
								// Region Footer triptych 2
								if ($page['footer_triptych_2']) :?>
									<div class="grid-4">
										<?php print render($page['footer_triptych_2']); ?>
									</div>
								<?php endif;
								
								// Region Footer triptych 3
								if ($page['footer_triptych_3']) :?>
									<div class="grid-4">
										<?php print render($page['footer_triptych_3']); ?>
									</div>
								<?php endif; ?>
							</div>
						</div>
					<?php endif;
					
					// Region Footer
					if ($page['footer_1']) : ?>
						<div class="region-footer-wrapper">
							<div class="container-12">
								<div class="grid-12">
									<?php print render($page['footer_1']); ?>
								</div>
							</div>
						</div>
					<?php endif;
					break;
			} ?>
		</footer>
	</div>
</div>