<?php

/**
 * @file
 * Theme settings for the Gatsby
 */
function gatsby_form_system_theme_settings_alter(&$form, &$form_state) {
	if (!isset($form['gatsby_settings'])) {
		/**
		 * Vertical tabs layout borrowed from Sasson.
		 *
		 * @link http://drupal.org/project/sasson
		 */
		drupal_add_css(drupal_get_path('theme', 'gatsby') . '/css/options/theme-settings.css', array(
			'group'				=> CSS_THEME,
			'every_page'		=> TRUE,
			'weight'			=> 99
		));
		
		// Enable/disable options wich are depends on modules
		$background_types = array(
			'none' => 'None',
			'video' => 'Video',
		);
		$note = '';
		
		if (module_exists ('media')) {
			$background_types['image'] = 'Image';
		} else {
			$note .= t('<p style="color: #f00">You should enable Media Module to use all of background settings!</p>');
		}
		
		// Typography
		$fonts = array (
					'Arial, Helvetica, sans-serif'							=> 'Arial, Helvetica, sans-serif',
					//'"Arial Black", Gadget, sans-serif'						=> '"Arial Black", Gadget, sans-serif',
					'"Comic Sans MS", Monaco, cursive'						=> '"Comic Sans MS", Monaco, cursive',
					'"Courier New", Courier, monospace'						=> '"Courier New", Courier, monospace',
					'Georgia, "Times New Roman", Times, serif'				=> 'Georgia, "Times New Roman", Times, serif',
					'Impact, Charcoal, sans-serif'							=> 'Impact, Charcoal, sans-serif',
					'"Lucida Console", Monaco, monospace'					=> '"Lucida Console", Monaco, monospace',
					'"Lucida Sans Unicode", "Lucida Grande", sans-serif'	=> '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
					'"Palatino Linotype", "Book Antiqua", Palatino, serif'	=> '"Palatino Linotype", "Book Antiqua", Palatino, serif',
					'Tahoma, Geneva, sans-serif'							=> 'Tahoma, Geneva, sans-serif',
					'"Times New Roman", Times, serif'						=> '"Times New Roman", Times, serif',
					'"Trebuchet MS", Arial, Helvetica, sans-serif'			=> '"Trebuchet MS", Arial, Helvetica, sans-serif',
					'Verdana, Geneva, sans-serif'							=> 'Verdana, Geneva, sans-serif',
					'Webfont'												=> 'Webfont',
		);
		
		// Color schemes
		$palette = array(
					'red'			=> '<span class="gatsby-color red"></span>' . t('Red'),
					'pink'			=> '<span class="gatsby-color pink"></span>' . t('Pink'),
					'purple'		=> '<span class="gatsby-color purple"></span>' . t('Purple'),
					'deep-purple'	=> '<span class="gatsby-color deep-purple"></span>' . t('Deep purple'),
					'indigo'		=> '<span class="gatsby-color indigo"></span>' . t('Indigo'),
					'blue'			=> '<span class="gatsby-color blue"></span>' . t('Blue'),
					'light-blue'	=> '<span class="gatsby-color light-blue"></span>' . t('Light blue'),
					'cyan'			=> '<span class="gatsby-color cyan"></span>' . t('Cyan'),
					'teal'			=> '<span class="gatsby-color teal"></span>' . t('Teal'),
					'green'			=> '<span class="gatsby-color green"></span>' . t('Green'),
					'light-green'	=> '<span class="gatsby-color light-green"></span>' . t('Light green'),
					'lime'			=> '<span class="gatsby-color lime"></span>' . t('Lime'),
					'yellow'		=> '<span class="gatsby-color yellow"></span>' . t('Yellow'),
					'amber'			=> '<span class="gatsby-color amber"></span>' . t('Amber'),
					'orange'		=> '<span class="gatsby-color orange"></span>' . t('Orange'),
					'deep-orange'	=> '<span class="gatsby-color deep-orange"></span>' . t('Deep orange'),
					'brown'			=> '<span class="gatsby-color brown"></span>' . t('Brown'),
					'grey'			=> '<span class="gatsby-color grey"></span>' . t('Grey'),
					'blue-gray'		=> '<span class="gatsby-color blue-gray"></span>' . t('Blue grey'),
					'black'			=> '<span class="gatsby-color black"></span>' . t('Black'),
				);
		
		/* Settings */
		$form['gatsby_settings'] = array(
			'#type'				=> 'vertical_tabs',
			'#weight'			=> -10,
		);
		
		/**
		 * General settings.
		 */
		$form['gatsby_settings']['gatsby_general'] = array(
			'#title'			=> t('General Settings'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_general']['theme_settings'] = $form['theme_settings'];
		unset($form['theme_settings']);

		$form['gatsby_settings']['gatsby_general']['logo'] = $form['logo'];
		unset($form['logo']);

		$form['gatsby_settings']['gatsby_general']['favicon'] = $form['favicon'];
		unset($form['favicon']);
		
		$form['gatsby_settings']['gatsby_general']['gatsby_styleswitcher_show'] = array(
			'#default_value'	=> theme_get_setting('gatsby_styleswitcher_show'),
			'#title'			=> t('Show the Style Switcher.'),
			'#type'				=> 'checkbox',
		);

		/**
		 * Navigation Settings
		 */
		$form['gatsby_settings']['gatsby_nav'] = array(
			'#title'			=> t('Navigation Settings'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_nav']['gatsby_menu'] = array(
			'#title'			=> t('Menu'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_nav']['gatsby_menu']['gatsby_sticky_menu'] = array(
			'#default_value'	=> theme_get_setting('gatsby_sticky_menu'),
			'#title'			=> t('Stick up menu.'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_nav']['gatsby_breadcrumb'] = array(
			'#title'			=> t('Breadcrumbs'),
			'#type'				=> 'fieldset',
		);

		$form['gatsby_settings']['gatsby_nav']['gatsby_breadcrumb']['gatsby_breadcrumb_show'] = array(
			'#default_value'	=> theme_get_setting('gatsby_breadcrumb_show'),
			'#title'			=> t('Show the breadcrumb.'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_nav']['gatsby_breadcrumb']['gatsby_breadcrumb_container'] = array(
			'#states'			=> array(
				'invisible'		=> array(
					'input[name="gatsby_breadcrumb_show"]' => array(
						'checked'	=> FALSE
					),
				),
			),
			'#type'				=> 'container',
		);

		$form['gatsby_settings']['gatsby_nav']['gatsby_breadcrumb']['gatsby_breadcrumb_container']['gatsby_breadcrumb_hideonlyfront'] = array(
			'#default_value'	=> theme_get_setting('gatsby_breadcrumb_hideonlyfront'),
			'#title'			=> t('Hide the breadcrumb if the breadcrumb only contains a link to the front page.'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_nav']['gatsby_breadcrumb']['gatsby_breadcrumb_container']['gatsby_breadcrumb_showtitle'] = array(
			'#default_value'	=> theme_get_setting('gatsby_breadcrumb_showtitle'),
			'#description'		=> t("Check this option to add the current page's title to the breadcrumb trail."),
			'#title'			=> t('Show page title on breadcrumb.'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_nav']['gatsby_breadcrumb']['gatsby_breadcrumb_container']['gatsby_breadcrumb_separator'] = array(
			'#default_value'	=> theme_get_setting('gatsby_breadcrumb_separator'),
			'#description'		=> t('Text only. Don\'t forget to include spaces.'),
			'#size'				=> 8,
			'#title'			=> t('Breadcrumb separator'),
			'#type'				=> 'textfield',
		);
		
		/**
		 * Styling Settings
		 */
		$form['gatsby_settings']['gatsby_styling'] = array(
			'#title'			=> t('Styling'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_styling']['gatsby_general_styling'] = array(
			'#title'			=> t('General styles'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_styling']['gatsby_general_styling']['gatsby_color_theme'] = array(
			'#default_value'	=> theme_get_setting('gatsby_color_theme'),
			'#options'			=> array(
									'dark' => '<span class="gatsby-color black"></span>' . t('Dark'),
									'light' => '<span class="gatsby-color white"></span>' . t('Light'),
								),
			'#title'			=> t("Select color palette"),
			'#type'				=> 'radios',
		);
		
		$form['gatsby_settings']['gatsby_styling']['gatsby_general_styling']['gatsby_color_palette'] = array(
			'#default_value'	=> theme_get_setting('gatsby_color_palette'),
			'#options'			=> $palette,
			'#title'			=> t("Select color palette"),
			'#type'				=> 'radios',
		);
		
		/**
		 * Typography
		 */
		$form['gatsby_settings']['gatsby_general_typography'] = array(
			'#title'			=> t('Typography'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_primary_typography'] = array(
			'#description'		=> t('Font for titles, buttons, etc.'),
			'#title'			=> t('Primary typography'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_primary_typography']['gatsby_primary_base_font_family'] = array(
			'#default_value' => theme_get_setting('gatsby_primary_base_font_family'),
			'#options' => $fonts,
			'#title' => t('Font family:'),
			'#type' => 'select',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_primary_typography']['gatsby_font_url_1'] = array(
			'#default_value'	=> theme_get_setting('gatsby_font_url_1'),
			'#description'		=> t('Input URL from Google fonts. Don\'t forget include bold and italic styles'),
			'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_primary_base_font_family"]' => array(
							'value'	=> 'Webfont'
						),
					),
				),
			'#title'			=> t('Webfont URL'),
			'#type'				=> 'textfield',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_primary_typography']['gatsby_primary_font_family'] = array(
			'#default_value'	=> theme_get_setting('gatsby_primary_font_family'),
			'#description'		=> t('Input name of font family'),
			'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_primary_base_font_family"]' => array(
							'value'	=> 'Webfont'
						),
					),
				),
			'#title'			=> t('Webfont family'),
			'#type'				=> 'textfield',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_secondary_typography'] = array(
			'#description'		=> t('Font for base text'),
			'#title'			=> t('Secondary typography'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_secondary_typography']['gatsby_secondary_base_font_family'] = array(
			'#default_value' => theme_get_setting('gatsby_secondary_base_font_family'),
			'#options' => $fonts,
			'#title' => t('Font family:'),
			'#type' => 'select',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_secondary_typography']['gatsby_font_url_2'] = array(
			'#default_value'	=> theme_get_setting('gatsby_font_url_2'),
			'#description'		=> t('Input URL from Google fonts. Don\'t forget include bold and italic styles'),
			'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_secondary_base_font_family"]' => array(
							'value'	=> 'Webfont'
						),
					),
				),
			'#title'			=> t('Webfont URL'),
			'#type'				=> 'textfield',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_secondary_typography']['gatsby_secondary_font_family'] = array(
			'#default_value'	=> theme_get_setting('gatsby_secondary_font_family'),
			'#description'		=> t('Input name of font family'),
			'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_secondary_base_font_family"]' => array(
							'value'	=> 'Webfont'
						),
					),
				),
			'#title'			=> t('Webfont family'),
			'#type'				=> 'textfield',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_secondary_typography']['gatsby_secondary_font_size'] = array(
			'#default_value'	=> theme_get_setting('gatsby_secondary_font_size'),
			'#description'		=> t('Input font size in px, em or pt'),
			'#title'			=> t('Font size'),
			'#type'				=> 'textfield',
		);
		
		$form['gatsby_settings']['gatsby_general_typography']['gatsby_secondary_typography']['gatsby_secondary_line_height'] = array(
			'#default_value'	=> theme_get_setting('gatsby_secondary_line_height'),
			'#description'		=> t('Input line height in px, em or pt'),
			'#title'			=> t('Line height'),
			'#type'				=> 'textfield',
		);

		/**
		 * Layout Settings
		 */
		$form['gatsby_settings']['gatsby_layout'] = array(
			'#description'		=> $note,
			'#title'			=> t('Layout Settings'),
			'#type'				=> 'fieldset',
		);
		
		// Layout style
		$form['gatsby_settings']['gatsby_layout']['gatsby_layout_opt'] = array(
			'#title'			=> t('General options'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_layout']['gatsby_layout_opt']['gatsby_layout_type'] = array(
			'#default_value' => theme_get_setting('gatsby_layout_type'),
			'#options' => array (
					'wide'		=> 'Wide',
					'boxed'		=> 'Boxed',
				),
			'#title' => t('Layout type:'),
			'#type' => 'select',
		);
		
		$form['gatsby_settings']['gatsby_layout']['gatsby_layout_opt']['gatsby_header_style'] = array(
			'#default_value' => theme_get_setting('gatsby_header_style'),
			'#options' => array (
					'header_1'	=> 'Header 1',
					'header_2'	=> 'Header 2',
					'header_3'	=> 'Header 3',
					'header_4'	=> 'Header 4',
					'header_5'	=> 'Header 5',
					'header_6'	=> 'Header 6',
					'header_7'	=> 'Header 7',
				),
			'#title' => t('Header style:'),
			'#type' => 'select',
		);
		
		$form['gatsby_settings']['gatsby_layout']['gatsby_layout_opt']['gatsby_footer_style'] = array(
			'#default_value' => theme_get_setting('gatsby_footer_style'),
			'#options' => array (
					'footer_1'	=> 'Footer 1',
					'footer_2'	=> 'Footer 2',
					'footer_3'	=> 'Footer 3',
				),
			'#title' => t('Footer style:'),
			'#type' => 'select',
		);

		$regions = array('Header section 1', 'Header section 2', 'Header section 3', 'Header section 4', 'Content top', 'Content section 1', 'Content section 2', 'Content section 3', 'Content section 4', 'Content section 5', 'Content section 6', 'Content section 7', 'Content section 8', 'Content section 9', 'Content section 10', 'Content section 11', 'Content section 12', 'Content section 13', 'Content section 14', 'Content section 15', 'Content section 16', 'Content section 17', 'Content section 18', 'Content section 19', 'Content section 20', 'Content section 21', 'Content section 22', 'Content section 23', 'Content section 24', 'Content section 25', 'Content section 26', 'Content section 27', 'Content section 28', 'Content section 29', 'Content section 30', 'Content bottom');
		
		for ($i = 0; $i < count($regions); $i++) {
			$regname = mb_strtolower (str_replace (' ', '_', $regions[$i]));
			
			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt'] = array(
				'#title'			=> t($regions[$i]),
				'#type'				=> 'fieldset',
			);

			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt']['gatsby_' . $regname . '_bg_type'] = array(
				'#default_value' => theme_get_setting('gatsby_' . $regname . '_bg_type'),
				'#options' => $background_types,
				'#title' => t('Background type:'),
				'#type' => 'select',
			);
			
			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt']['gatsby_' . $regname . '_bg_img'] = array(
				'#default_value' => theme_get_setting('gatsby_' . $regname . '_bg_img'),
				'#description' => t('Choose block background image.'),
				'#media_options' => array(
					'global' => array(
						'types' => array(
							'image' => 'image',
						),
						'schemes' => array(
							'public' => 'public',
						),
						'file_extensions' => 'png gif jpg jpeg',
						'max_filesize' => '1 MB',
						'uri_scheme' => 'public',
					),
				),
				'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_' . $regname . '_bg_type"]' => array(
							'value'	=> 'image'
						),
					),
				),
				'#title' => t('Background image URL'),
				'#tree' => TRUE,
				'#type' => 'media',
			);
			
			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt']['gatsby_' . $regname . '_bg_parallax'] = array(
				'#default_value' =>  theme_get_setting('gatsby_' . $regname . '_bg_parallax'),
				'#description'		=> '',
				'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_' . $regname . '_bg_type"]' => array(
							'value'	=> 'image'
						),
					),
				),
				'#title' => t('Use parallax'),
				'#type' => 'checkbox',
			);

			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt']['gatsby_' . $regname . '_bg_video'] = array(
				'#default_value'	=> theme_get_setting('gatsby_' . $regname . '_bg_video'),
				'#description'		=> t('Enter video URL. Supports youtube video. '),
				'#size'				=> 60,
				'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_' . $regname . '_bg_type"]' => array(
							'value'	=> 'video'
						),
					),
				),
				'#title'			=> t('Background Video URL'),
				'#type'				=> 'textfield',
			);

			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt']['gatsby_' . $regname . '_bg_video_start'] = array(
				'#default_value'	=> theme_get_setting('gatsby_' . $regname . '_bg_video_start'),
				'#description'		=> t('Enter time in seconds. '),
				'#size'				=> 8,
				'#states'			=> array(
					'visible'		=> array(
						'select[name="gatsby_' . $regname . '_bg_type"]' => array(
							'value'	=> 'video'
						),
					),
				),
				'#title'			=> t('Start video at'),
				'#type'				=> 'textfield',
			);

			$form['gatsby_settings']['gatsby_layout']['gatsby_' . $regname . '_opt']['gatsby_' . $regname . '_fullwidth'] = array(
				'#default_value'	=> theme_get_setting('gatsby_' . $regname . '_fullwidth'),
				'#description'		=> t("Check this option to make this region fullwidth (e.g. remove grids)."),
				'#title'			=> t('Fullwidth'),
				'#type'				=> 'checkbox',
			);
		}
		
		/**
		 * Post Settings
		 */
		$form['gatsby_settings']['gatsby_posts'] = array(
			'#title'			=> t('Post Settings'),
			'#type'				=> 'fieldset',
		);
		
		// Post meta
		$form['gatsby_settings']['gatsby_posts']['gatsby_meta'] = array(
			'#title'			=> t('Meta information'),
			'#type'				=> 'fieldset',
		);
		unset($form['gatsby_settings']['gatsby_general']['theme_settings']['toggle_node_user_picture']);

		$form['gatsby_settings']['gatsby_posts']['gatsby_meta']['gatsby_meta_author'] = array(
			'#default_value'	=> theme_get_setting('gatsby_meta_author'),
			'#title'			=> t('Display post author'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_meta']['gatsby_meta_date'] = array(
			'#default_value'	=> theme_get_setting('gatsby_meta_date'),
			'#title'			=> t('Display post pabdate'),
			'#type'				=> 'checkbox',
		);

		if (module_exists('statistics')) {
			$form['gatsby_settings']['gatsby_posts']['gatsby_meta']['gatsby_meta_views'] = array(
				'#default_value'	=> theme_get_setting('gatsby_meta_views'),
				'#title'			=> t('Display number of post views'),
				'#type'				=> 'checkbox',
			);
		}

		$form['gatsby_settings']['gatsby_posts']['gatsby_meta']['gatsby_meta_comments'] = array(
			'#default_value'	=> theme_get_setting('gatsby_meta_comments'),
			'#title'			=> t('Display post pabdate'),
			'#type'				=> 'checkbox',
		);
		
		// Post links
		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links'] = array(
			'#title'			=> t('Links'),
			'#type'				=> 'fieldset',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links']['gatsby_links_hide_readmore'] = array(
			'#default_value'	=> theme_get_setting('gatsby_links_hide_readmore'),
			'#title'			=> t('Hide "Read more" link'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links']['gatsby_links_readmore_title'] = array(
			'#default_value'	=> theme_get_setting('gatsby_links_readmore_title'),
			'#states'			=> array(
					'visible'		=> array(
						'input[name="gatsby_links_hide_readmore"]' => array(
							'checked'	=> FALSE,
						),
					),
				),
			'#title'			=> t('Read more title'),
			'#type'				=> 'textfield',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links']['gatsby_links_hide_readblog'] = array(
			'#default_value'	=> theme_get_setting('gatsby_links_hide_readblog'),
			'#title'			=> t('Hide "Read user\'s blog" link'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links']['gatsby_links_hide_addcomment'] = array(
			'#default_value'	=> theme_get_setting('gatsby_links_hide_addcomment'),
			'#title'			=> t('Hide "Add new comment" link'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links']['gatsby_links_hide_commentsnum'] = array(
			'#default_value'	=> theme_get_setting('gatsby_links_hide_commentsnum'),
			'#title'			=> t('Hide number of comments'),
			'#type'				=> 'checkbox',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_post_links']['gatsby_links_hide_commentsnew'] = array(
			'#default_value'	=> theme_get_setting('gatsby_links_hide_commentsnew'),
			'#title'			=> t('Hide number of new comments'),
			'#type'				=> 'checkbox',
		);
		
		// Comments
		$form['gatsby_settings']['gatsby_posts']['gatsby_comments'] = array(
			'#title'			=> t('Comments'),
			'#type'				=> 'fieldset',
		);

		$form['gatsby_settings']['gatsby_posts']['gatsby_comments']['toggle_comment_user_picture'] = $form['gatsby_settings']['gatsby_general']['theme_settings']['toggle_comment_user_picture'];
		unset($form['gatsby_settings']['gatsby_general']['theme_settings']['toggle_comment_user_picture']);

		$form['gatsby_settings']['gatsby_posts']['gatsby_comments']['toggle_comment_user_verification'] = $form['gatsby_settings']['gatsby_general']['theme_settings']['toggle_comment_user_verification'];
		unset($form['gatsby_settings']['gatsby_general']['theme_settings']['toggle_comment_user_verification']);

		/**
		 * Custom CSS
		 */
		$form['gatsby_settings']['gatsby_css'] = array(
			'#title'			=> t('Custom CSS'),
			'#type'				=> 'fieldset',
		);
		
		$form['gatsby_settings']['gatsby_css']['css'] = array(
			'#title'			=> t('Custom CSS'),
			'#type'				=> 'fieldset',
		);

		$form['gatsby_settings']['gatsby_css']['css']['gatsby_custom_css'] = array(
			'#default_value'	=> theme_get_setting('gatsby_custom_css'),
			'#title'			=> t('Insert your CSS code here:'),
			'#type'				=> 'textarea',
		);
		
		
		/* Submit function */
		$form['#submit'][] = 'gatsby_form_system_theme_settings_submit';

		/* Add reset button */
		$form['actions']['reset'] = array(
			'#submit' => array('gatsby_form_system_theme_settings_reset'),
			'#type' => 'submit',
			'#value' => t('Reset to defaults'),
		);
		
		$theme_settings_path = drupal_get_path('theme', 'gatsby') . '/theme-settings.php';
		if (file_exists($theme_settings_path) && !in_array($theme_settings_path, $form_state['build_info']['files'])) {
			$form_state['build_info']['files'][] = $theme_settings_path;
		}
	}
}

/* File wrhite */
function gatsby_fwrite($local_url, $content) {
	$fp = fopen(drupal_get_path('theme', 'gatsby') . $local_url, 'a');
	ftruncate($fp, 0);
	fwrite($fp, $content);
	fclose($fp);
}

/* Color schemes */
function gatsby_color_scheme_vars(
		$opt = array(
			'theme' => "light",
			'palette' => "grey",
			/*$accent_color => "red",*/
			'primary_base_font_family' => "Webfont",
			'font_url_1' => "//fonts.googleapis.com/css?family=Open+Sans:400,400italic,700,700italic&subset=latin,cyrillic",
			'primary_font_family' => "'Open Sans', sans-serif",
			'secondary_base_font_family' => "Webfont",
			'font_url_2' => "//fonts.googleapis.com/css?family=Open+Sans:400,400italic,700,700italic&subset=latin,cyrillic",
			'secondary_font_family' => "'Open Sans', sans-serif",
			'secondary_font_size' => "14px",
			'secondary_line_height' => "20px"
		)) {
	$output = '';
	
	$output = '/* ' . $opt['palette'] . ' palette */';
	
	if ($opt['primary_base_font_family'] == 'Webfont' && $opt['font_url_1'] != '') {
		$output .= '
@import url(' . $opt['font_url_1'] . ');';
	}
	if ($opt['secondary_base_font_family'] == 'Webfont' && $opt['font_url_2'] != $opt['font_url_1'] && $opt['font_url_2'] != '') {
		$output .= '
@import url(' . $opt['font_url_2'] . ');';
	}
	
	switch ($opt['palette']) {
		case 'amber':
			$darkPrimaryColor			= '#ffa000';
			$primaryColor				= '#ffc107';
			break;
		case 'black':
			$darkPrimaryColor			= '#000000';
			$primaryColor				= '#212121';
			break;
		case 'blue':
			$darkPrimaryColor			= '#1976d2';
			$primaryColor				= '#2196f3';
			break;
		case 'blue-gray':
			$darkPrimaryColor			= '#455a64';
			$primaryColor				= '#607d8b';
			break;
		case 'brown':
			$darkPrimaryColor			= '#5d4037';
			$primaryColor				= '#795548';
			break;
		case 'cyan':
			$darkPrimaryColor			= '#0097a7';
			$primaryColor				= '#00bcd4';
			break;
		case 'deep-orange':
			$darkPrimaryColor			= '#e64a19';
			$primaryColor				= '#ff5722';
			break;
		case 'deep-purple':
			$darkPrimaryColor			= '#512da8';
			$primaryColor				= '#673ab7';
			break;
		case 'green':
			$darkPrimaryColor			= '#388e3c';
			$primaryColor				= '#4caf50';
			break;
		case 'grey':
			$darkPrimaryColor			= '#787878';
			$primaryColor				= '#9e9e9e';
			break;
		case 'indigo':
			$darkPrimaryColor			= '#303f9f';
			$primaryColor				= '#3f51b5';
			break;
		case 'light-blue':
			$darkPrimaryColor			= '#0288d1';
			$primaryColor				= '#03a9f4';
			break;
		case 'light-green':
			$darkPrimaryColor			= '#689f38';
			$primaryColor				= '#8bc34a';
			break;
		case 'lime':
			$darkPrimaryColor			= '#afb42b';
			$primaryColor				= '#cddc39';
			$middlePrimaryTextColor		= 'rgba(0, 0, 0, .87)';
			$middleSecondaryTextColor	= 'rgba(0, 0, 0, .54)';
			$middleBorderColor			= 'rgba(0, 0, 0, .12)';
			break;
		case 'orange':
			$darkPrimaryColor			= '#f57c00';
			$primaryColor				= '#ff9800';
			break;
		case 'pink':
			$darkPrimaryColor			= '#c2185b';
			$primaryColor				= '#e91e63';
			break;
		case 'purple':
			$darkPrimaryColor			= '#7b1fa2';
			$primaryColor				= '#9c27b0';
			break;
		case 'red':
			$darkPrimaryColor			= '#d32f2f';
			$primaryColor				= '#f44336';
			break;
		case 'teal':
			$darkPrimaryColor			= '#00796b';
			$primaryColor				= '#009688';
			break;
		case 'yellow':
			$darkPrimaryColor			= '#fbc02d';
			$primaryColor				= '#fff176';
			$middlePrimaryTextColor		= 'rgba(0, 0, 0, .87)';
			$middleSecondaryTextColor	= 'rgba(0, 0, 0, .54)';
			$middleBorderColor			= 'rgba(0, 0, 0, .12)';
			break;
	}
	
	switch ($opt['theme']) {
		case 'dark':
			$lightPrimaryColor			= '#424242';
			$darkPrimaryTextColor		= 'rgba(255, 255, 255, 1)';
			$darkSecondaryTextColor		= 'rgba(255, 255, 255, .7)';
			$darkBorderColor			= 'rgba(0, 0, 0, .2)';
			$baseColor					= '#303030';
			$primaryTextColor			= '#ffffff';
			$secondaryTextColor			= 'rgba(255, 255, 255, .7)';
			$borderColor				= 'rgba(255, 255, 255, .2)';
			break;
		case 'light':
			$lightPrimaryColor			= '#f3f3f3';
			$darkPrimaryTextColor		= 'rgba(0, 0, 0, .87)';
			$darkSecondaryTextColor		= 'rgba(0, 0, 0, .54)';
			$darkBorderColor			= 'rgba(0, 0, 0, .2)';
			$baseColor					= '#ffffff';
			$primaryTextColor			= 'rgba(0, 0, 0, .87)';
			$secondaryTextColor			= 'rgba(0, 0, 0, .54)';
			$borderColor				= 'rgba(0, 0, 0, .12)';
			break;
	}
	
	/*switch ($opt['accent_color']) {
		case 'amber':
			$accentColor = '#ffc107';
			break;
		case 'black':
			$accentColor = '#000000';
			break;
		case 'blue':
			$accentColor = '#448aff';
			break;
		case 'blue-gray':
			$accentColor = '#607d8b';
			break;
		case 'brown':
			$accentColor = '#795548';
			break;
		case 'cyan':
			$accentColor = '#00bcd4';
			break;
		case 'deep-orange':
			$accentColor = '#ff5722';
			break;
		case 'deep-purple':
			$accentColor = '#7c4dff';
			break;
		case 'green':
			$accentColor = '#4caf50';
			break;
		case 'grey':
			$accentColor = '#9e9e9e';
			break;
		case 'indigo':
			$accentColor = '#536dfe';
			break;
		case 'light-blue':
			$accentColor = '#03a9f4';
			break;
		case 'light-green':
			$accentColor = '#8bc34a';
			break;
		case 'lime':
			$accentColor = '#cddc39';
			break;
		case 'orange':
			$accentColor = '#ff9800';
			break;
		case 'pink':
			$accentColor = '#ff4081';
			break;
		case 'purple':
			$accentColor = '#e040fb';
			break;
		case 'red':
			$accentColor = '#ff5252';
			break;
		case 'teal':
			$accentColor = '#009688';
			break;
		case 'yellow':
			$accentColor = '#ffeb3b';
			break;
	}*/
	
	if (!isset($lightPrimaryTextColor)) { $lightPrimaryTextColor = '#ffffff'; }
	if (!isset($lightSecondaryTextColor)) { $lightSecondaryTextColor = 'rgba(255, 255, 255, .6)'; }
	if (!isset($lightBorderColor)) { $lightBorderColor = 'rgba(255, 255, 255, .2)'; }
	if (!isset($middlePrimaryTextColor)) { $middlePrimaryTextColor = '#ffffff'; }
	if (!isset($middleSecondaryTextColor)) { $middleSecondaryTextColor = 'rgba(255, 255, 255, .6)'; }
	if (!isset($middleBorderColor)) { $middleBorderColor = 'rgba(255, 255, 255, .2)'; }
	if (!isset($accentColor)) { $accentColor = $primaryColor; }
	
	$secondary_font_family = $opt['secondary_base_font_family'] == 'Webfont' ? $opt['secondary_font_family'] : $opt['secondary_base_font_family'];
	$primary_font_family = $opt['primary_base_font_family'] == 'Webfont' ? $opt['primary_font_family'] : $opt['primary_base_font_family'];
	
	$output .= '

@darkPrimaryColor:			' . $darkPrimaryColor . ';
@lightPrimaryTextColor:		' . $lightPrimaryTextColor . ';
@lightSecondaryTextColor:	' . $lightSecondaryTextColor . ';
@lightBorderColor:			' . $lightBorderColor . ';
@lightAccentColor:			lighten(' . $accentColor . ', 10%);

@primaryColor:				' . $primaryColor . ';
@middlePrimaryTextColor:	' . $middlePrimaryTextColor . ';
@middleSecondaryTextColor:	' . $middleSecondaryTextColor . ';
@middleBorderColor:			' . $middleBorderColor . ';
@middleAccentColor:			darken(' . $accentColor . ', 30%);

@lightPrimaryColor:			' . $lightPrimaryColor . ';
@darkPrimaryTextColor:		' . $darkPrimaryTextColor . ';
@darkSecondaryTextColor:	' . $darkSecondaryTextColor . ';
@darkBorderColor:			' . $darkBorderColor . ';
@darkAccentColor:			' . $accentColor . ';

@baseColor:					' . $baseColor . ';
@primaryTextColor:			' . $primaryTextColor . ';
@secondaryTextColor:		' . $secondaryTextColor . ';
@borderColor:				' . $borderColor . ';
@accentColor:				' . $accentColor . ';

@secondaryFontSize:			' . $opt['secondary_font_size'] . ';
@secondaryLineHeight:		' . $opt['secondary_line_height'] . ';
@secondaryFontFamily:		' . $secondary_font_family . ';
@primaryFontFamily:			' . $primary_font_family . ';
@monospaseFontFamily:		\'Courier New\', Courier, monospace;

@white:						#ffffff;
@black:						#000000;';
	
	return $output;
}


/* Save options */
function gatsby_form_system_theme_settings_submit($form, &$form_state) {
	// Custom CSS
	gatsby_fwrite('/css/custom.css', $form_state['values']['gatsby_custom_css']);
	
	// Color schemes
	$opt = array(
			'theme' => $form_state['values']['gatsby_color_theme'],
			'palette' => $form_state['values']['gatsby_color_palette'],
			/*'accent_color' => $form_state['values']['gatsby_accent_color'],*/
			'primary_base_font_family' => $form_state['values']['gatsby_primary_base_font_family'],
			'font_url_1' => $form_state['values']['gatsby_font_url_1'],
			'primary_font_family' => $form_state['values']['gatsby_primary_font_family'],
			'secondary_base_font_family' => $form_state['values']['gatsby_secondary_base_font_family'],
			'font_url_2' => $form_state['values']['gatsby_font_url_2'],
			'secondary_font_family' => $form_state['values']['gatsby_secondary_font_family'],
			'secondary_font_size' => $form_state['values']['gatsby_secondary_font_size'],
			'secondary_line_height' => $form_state['values']['gatsby_secondary_line_height']
		);
	$scheme_vars = gatsby_color_scheme_vars ($opt);
	gatsby_fwrite('/less/variables.less', $scheme_vars);
}

/* Reset options */
function gatsby_form_system_theme_settings_reset($form, &$form_state) {
	form_state_values_clean($form_state);
	variable_del('theme_gatsby_settings');
	
	// Custom CSS
	gatsby_fwrite('/css/custom.css', '');
	
	// Color schemes
	$scheme_vars = gatsby_color_scheme_vars ();
	gatsby_fwrite('/less/variables.less', $scheme_vars);

	drupal_set_message(t('The configuration options have been reset to their default values.'));
}